#!/bin/bash

##############################################################################
#
# MODULE:       r.avaflow.install.sh
#
# AUTHOR:       Martin Mergili, Andreas Huber and Jan-Thomas Fischer
#
# PURPOSE:      The open source GIS simulation model
#               for granular avalanches and debris flows
#               Installation script
#
# COPYRIGHT:    (c) 2010 - 2016 by the author
#               (c) 2010 - 2016 by the BOKU University, Vienna
#               (c) 2015 - 2016 by the University of Vienna
#               (c) 2016        by the BFW, Innsbruck
#               (c) 2000 - 2016 by the GRASS Development Team
#
# VERSION:      20160802 (2 August 2016)
#
#               This program is free software under the GNU General Public
#               License (>=v2). Read the file COPYING that comes with GRASS
#               for details.
#
##############################################################################


echo ""

pathmain=`pwd`

PATHGRASS="/usr/lib/grass70/"
PATHPYTHON="/usr/lib/python2.7/"
PATHDOCS="/usr/share/doc/grass-doc/html/"

#INSTALLING R- AND PYTHON-BASED MODULES FOR DATA MANAGEMENT
#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Installing R scripts and Python library
cp r.avaflow.hydrograph.r "$PATHGRASS"scripts/r.avaflow.hydrograph.r
cp r.avaflow.map.r "$PATHGRASS"scripts/r.avaflow.map.r
cp r.avaflow.profile.r "$PATHGRASS"scripts/r.avaflow.profile.r
cp r.avaflow.roc.r "$PATHGRASS"scripts/r.avaflow.roc.r
cp images2gif.py "$PATHPYTHON"images2gif.py

#Installing Python scripts
cp r.avaflow.py "$PATHGRASS"scripts/r.avaflow
chmod +x "$PATHGRASS"scripts/r.avaflow
cp r.avaflow.mult.py "$PATHGRASS"scripts/r.avaflow.mult
chmod +x "$PATHGRASS"scripts/r.avaflow.mult

#Installing manual
cp r.avaflow.html "$PATHDOCS"

#Returning to initial directory
cd $pathmain

#Installing C script r.avaflow.main.c
#Creating directory for raster module
if [ ! -d "$PATHGRASS"raster ]
then
    mkdir "$PATHGRASS"raster
fi

#Removing directory with installation files, if existing
if [ -d "$PATHGRASS"raster/r.avaflow.main ]
then
    rm -rf "$PATHGRASS"raster/r.avaflow.main
fi

if [ -f "$PATHGRASS"bin/r.avaflow.main ]
then
    rm "$PATHGRASS"bin/r.avaflow.main
fi

#Creating directory for installation files and copying r.avaflow.main.c
mkdir "$PATHGRASS"raster/r.avaflow.main
cp r.avaflow.main.c "$PATHGRASS"raster/r.avaflow.main/main.c
cp r.avaflow.html "$PATHDOCS"/r.avaflow.main.html

#Moving to the directory for installation files
cd "$PATHGRASS"raster/r.avaflow.main

# Creating makefile
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.avaflow.main" >> Makefile
echo "" >> Makefile
echo "LIBES = \$(GPROJDEP) \$(GISLIB) \$(SEGMENTLIB) \$(RASTERLIB) \$(GMATHLIB)" >> Makefile
echo "DEPENDENCIES = \$(GPROJDEP) \$(GISDEP) \$(GMATHDEP)" >> Makefile
echo "EXTRA_INC = \$(PROJINC)" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Module.make" >> Makefile
echo "" >> Makefile
echo "default: cmd" >> Makefile
echo "CFLAGS = -w" >> Makefile

# Installing r.avaflow.main
INST_NOW=y make

echo ""
echo "Installation completed. Please check for possible error messages. "
echo "Press ENTER for exit. "
read answer

#Returning to initial directory and terminating sudo mode
cd $pathmain
sudo -k
clear
